summaryrefslogtreecommitdiffstats
path: root/src/svnfrontend/svnactions.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/svnfrontend/svnactions.cpp')
-rw-r--r--src/svnfrontend/svnactions.cpp88
1 files changed, 44 insertions, 44 deletions
diff --git a/src/svnfrontend/svnactions.cpp b/src/svnfrontend/svnactions.cpp
index 6374ac5..6e102ea 100644
--- a/src/svnfrontend/svnactions.cpp
+++ b/src/svnfrontend/svnactions.cpp
@@ -78,10 +78,10 @@
#include <tqstring.h>
#include <tqmap.h>
#include <tqpushbutton.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqvaluelist.h>
#include <tqvbox.h>
-#include <stylesheet.h>
+#include <tqstylesheet.h>
#include <tqregexp.h>
#include <tqimage.h>
#include <tqthread.h>
@@ -442,7 +442,7 @@ void SvnActions::makeTree(const TQString&what,const svn::Revision&_rev,const svn
}
kdDebug()<<"Logs for "<<reposRoot<<endl;
TQWidget*disp;
- KDialogBase dlg(m_Data->m_ParentList->realWidget(),"historylist",true,i18n("History of %1").arg(info.url().mid(reposRoot.length())),
+ KDialogBase dlg(m_Data->m_ParentList->realWidget(),"historylist",true,i18n("History of %1").tqarg(info.url().mid(reposRoot.length())),
KDialogBase::Ok,
KDialogBase::Ok,true);
TQWidget* Dialog1Layout = dlg.makeVBoxMainWidget();
@@ -599,7 +599,7 @@ void SvnActions::slotMakeCat(const svn::Revision&start, const TQString&what, con
TQByteArray co = file.readAll();
if (co.size()) {
- KDialogBase*dlg = createDialog(&ptr,TQString(i18n("Content of %1")).arg(disp),false,"cat_display_dlg");
+ KDialogBase*dlg = createDialog(&ptr,TQString(i18n("Content of %1")).tqarg(disp),false,"cat_display_dlg");
if (dlg) {
ptr->setFont(KGlobalSettings::fixedFont());
ptr->setWordWrap(TQTextEdit::NoWrap);
@@ -791,7 +791,7 @@ TQString SvnActions::getInfo(const TQString& _what,const svn::Revision&rev,const
text+=rb+i18n("Lock comment")+cs+
(*it).lockEntry().Comment()+re;
} else {
- svn::SharedPointer<svn::Status> d;
+ svn::SharedPointer<svn::tqStatus> d;
if (checkReposLockCache(_what,d)&& d && d->lockEntry().Locked()) {
text+=rb+i18n("Lock token")+cs+(d->lockEntry().Token())+re;
text+=rb+i18n("Owner")+cs+(d->lockEntry().Owner())+re;
@@ -876,7 +876,7 @@ void SvnActions::slotProperties()
TQValueList<TQString> delList;
dlg.changedItems(setList,delList);
changeProperties(setList,delList,k->fullName());
- k->refreshStatus();
+ k->refreshtqStatus();
EMIT_FINISHED;
}
@@ -972,18 +972,18 @@ bool SvnActions::makeCommit(const svn::Targets&targets)
for (unsigned int i = 0; i < _Cache.count();++i) {
_p = _Cache[i]->path();
if (_Cache[i]->isRealVersioned()&& (
- _Cache[i]->textStatus()==svn_wc_status_modified||
- _Cache[i]->textStatus()==svn_wc_status_added||
- _Cache[i]->textStatus()==svn_wc_status_replaced||
- _Cache[i]->textStatus()==svn_wc_status_deleted||
- _Cache[i]->propStatus()==svn_wc_status_modified
+ _Cache[i]->texttqStatus()==svn_wc_status_modified||
+ _Cache[i]->texttqStatus()==svn_wc_status_added||
+ _Cache[i]->texttqStatus()==svn_wc_status_replaced||
+ _Cache[i]->texttqStatus()==svn_wc_status_deleted||
+ _Cache[i]->proptqStatus()==svn_wc_status_modified
) ) {
- if (_Cache[i]->textStatus()==svn_wc_status_deleted) {
+ if (_Cache[i]->texttqStatus()==svn_wc_status_deleted) {
_check.append(Logmsg_impl::logActionEntry(_p,i18n("Delete"),Logmsg_impl::logActionEntry::DELETE));
} else {
_check.append(Logmsg_impl::logActionEntry(_p,i18n("Commit"),Logmsg_impl::logActionEntry::COMMIT));
}
- } else if (_Cache[i]->textStatus()==svn_wc_status_missing) {
+ } else if (_Cache[i]->texttqStatus()==svn_wc_status_missing) {
_uncheck.append(Logmsg_impl::logActionEntry(_p,i18n("Delete and Commit"),Logmsg_impl::logActionEntry::MISSING_DELETE));
} else if (!_Cache[i]->isVersioned()) {
_uncheck.append(Logmsg_impl::logActionEntry(_p,i18n("Add and Commit"),Logmsg_impl::logActionEntry::ADD_COMMIT));
@@ -1031,7 +1031,7 @@ bool SvnActions::makeCommit(const svn::Targets&targets)
return false;
}
EMIT_REFRESH;
- emit sendNotify(i18n("Committed revision %1.").arg(nnum.toString()));
+ emit sendNotify(i18n("Committed revision %1.").tqarg(nnum.toString()));
return true;
}
@@ -1232,7 +1232,7 @@ void SvnActions::makeDiffinternal(const TQString&p1,const svn::Revision&r1,const
TQByteArray ex;
KTempDir tdir;
tdir.setAutoDelete(true);
- TQString tn = TQString("%1/%2").arg(tdir.name()).arg("/svndiff");
+ TQString tn = TQString("%1/%2").tqarg(tdir.name()).tqarg("/svndiff");
bool ignore_content = Kdesvnsettings::diff_ignore_content();
TQWidget*parent = p?p:m_Data->m_ParentList->realWidget();
TQStringList extraOptions;
@@ -1296,7 +1296,7 @@ void SvnActions::makeNorecDiff(const TQString&p1,const svn::Revision&r1,const TQ
KTempDir tdir;
tdir.setAutoDelete(true);
kdDebug()<<"Non recourse diff"<<endl;
- TQString tn = TQString("%1/%2").arg(tdir.name()).arg("/svndiff");
+ TQString tn = TQString("%1/%2").tqarg(tdir.name()).tqarg("/svndiff");
bool ignore_content = Kdesvnsettings::diff_ignore_content();
try {
StopDlg sdlg(m_Data->m_SvnContextListener,_p?_p:m_Data->m_ParentList->realWidget(),0,"Diffing","Diffing - hit cancel for abort");
@@ -1458,8 +1458,8 @@ void SvnActions::prepareUpdate(bool ask)
return;
}
rdlg->setStartOnly(true);
- /* just here cause layout has changed meanwhile */
- dlg->resize( TQSize(120,60).expandedTo(dlg->minimumSizeHint()) );
+ /* just here cause tqlayout has changed meanwhile */
+ dlg->resize( TQSize(120,60).expandedTo(dlg->tqminimumSizeHint()) );
int result;
if ((result=dlg->exec())==TQDialog::Accepted) {
Rangeinput_impl::revision_range range = rdlg->getRange();
@@ -1511,7 +1511,7 @@ void SvnActions::makeAdd(bool rec)
++liter;
if (cur->isVersioned()) {
KMessageBox::error(m_Data->m_ParentList->realWidget(),i18n("<center>The entry<br>%1<br>is versioned - break.</center>")
- .arg(cur->fullName()));
+ .tqarg(cur->fullName()));
return;
}
items.push_back(svn::Path(cur->fullName()));
@@ -1521,7 +1521,7 @@ void SvnActions::makeAdd(bool rec)
#if 0
while ((cur=liter.current())!=0){
++liter;
- //cur->refreshStatus();
+ //cur->refreshtqStatus();
//emit sigRefreshCurrent(static_cast<FileListViewItem*>(cur->parent()));
}
@@ -1721,7 +1721,7 @@ void SvnActions::slotRevert()
while ((cur=liter.current())!=0){
if (!cur->isVersioned()) {
KMessageBox::error(m_Data->m_ParentList->realWidget(),i18n("<center>The entry<br>%1<br>is not versioned - break.</center>")
- .arg(cur->fullName()));
+ .tqarg(cur->fullName()));
return;
}
displist.append(cur->fullName());
@@ -2178,7 +2178,7 @@ bool SvnActions::makeMove(const TQString&Old,const TQString&New,bool force)
return false;
}
if (nnum != svn::Revision::UNDEFINED) {
- emit sendNotify(i18n("Committed revision %1.").arg(nnum.toString()));
+ emit sendNotify(i18n("Committed revision %1.").tqarg(nnum.toString()));
}
EMIT_REFRESH;
return true;
@@ -2295,15 +2295,15 @@ void SvnActions::makeUnlock(const TQStringList&what,bool breakit)
/*!
- \fn SvnActions::makeStatus(const TQString&what, svn::StatusEntries&dlist)
+ \fn SvnActions::maketqStatus(const TQString&what, svn::StatusEntries&dlist)
*/
-bool SvnActions::makeStatus(const TQString&what, svn::StatusEntries&dlist, svn::Revision&where,bool rec,bool all)
+bool SvnActions::maketqStatus(const TQString&what, svn::StatusEntries&dlist, svn::Revision&where,bool rec,bool all)
{
bool display_ignores = Kdesvnsettings::display_ignored_files();
- return makeStatus(what,dlist,where,rec,all,display_ignores);
+ return maketqStatus(what,dlist,where,rec,all,display_ignores);
}
-bool SvnActions::makeStatus(const TQString&what, svn::StatusEntries&dlist, svn::Revision&where,bool rec,bool all,bool display_ignores,bool updates)
+bool SvnActions::maketqStatus(const TQString&what, svn::StatusEntries&dlist, svn::Revision&where,bool rec,bool all,bool display_ignores,bool updates)
{
bool disp_remote_details = Kdesvnsettings::details_on_remote_listing();
TQString ex;
@@ -2326,7 +2326,7 @@ void SvnActions::checkAddItems(const TQString&path,bool print_error_box)
svn::StatusEntries rlist;
TQStringList displist;
svn::Revision where = svn::Revision::HEAD;
- if (!makeStatus(path,dlist,where,true,true,false,false)) {
+ if (!maketqStatus(path,dlist,where,true,true,false,false)) {
return;
}
for (unsigned int i = 0; i<dlist.size();++i) {
@@ -2402,7 +2402,7 @@ void SvnActions::stopFillCache()
}
delete m_FCThread;
m_FCThread = 0;
- emit sigCacheStatus(-1,-1);
+ emit sigCachetqStatus(-1,-1);
}
}
@@ -2446,14 +2446,14 @@ void SvnActions::checkModthread()
for (unsigned int i = 0; i < m_CThread->getList().count();++i) {
svn::StatusPtr ptr = m_CThread->getList()[i];
if (m_CThread->getList()[i]->isRealVersioned()&& (
- m_CThread->getList()[i]->textStatus()==svn_wc_status_modified||
- m_CThread->getList()[i]->textStatus()==svn_wc_status_added||
- m_CThread->getList()[i]->textStatus()==svn_wc_status_deleted||
- m_CThread->getList()[i]->textStatus()==svn_wc_status_replaced||
- m_CThread->getList()[i]->propStatus()==svn_wc_status_modified
+ m_CThread->getList()[i]->texttqStatus()==svn_wc_status_modified||
+ m_CThread->getList()[i]->texttqStatus()==svn_wc_status_added||
+ m_CThread->getList()[i]->texttqStatus()==svn_wc_status_deleted||
+ m_CThread->getList()[i]->texttqStatus()==svn_wc_status_replaced||
+ m_CThread->getList()[i]->proptqStatus()==svn_wc_status_modified
) ) {
m_Data->m_Cache.insertKey(ptr,ptr->path());
- } else if (m_CThread->getList()[i]->textStatus()==svn_wc_status_conflicted) {
+ } else if (m_CThread->getList()[i]->texttqStatus()==svn_wc_status_conflicted) {
m_Data->m_conflictCache.insertKey(ptr,ptr->path());
}
}
@@ -2478,11 +2478,11 @@ void SvnActions::checkUpdateThread()
bool newer=false;
for (unsigned int i = 0; i < m_UThread->getList().count();++i) {
svn::StatusPtr ptr = m_UThread->getList()[i];
- if (ptr->validReposStatus()) {
+ if (ptr->validRepostqStatus()) {
m_Data->m_UpdateCache.insertKey(ptr,ptr->path());
- ptr->textStatus();
- ptr->propStatus();
- if (!(ptr->validLocalStatus())) {
+ ptr->texttqStatus();
+ ptr->proptqStatus();
+ if (!(ptr->validLocaltqStatus())) {
newer = true;
}
}
@@ -2514,7 +2514,7 @@ bool SvnActions::checkUpdatesRunning()
void SvnActions::addModifiedCache(const svn::StatusPtr&what)
{
- if (what->textStatus()==svn_wc_status_conflicted) {
+ if (what->texttqStatus()==svn_wc_status_conflicted) {
m_Data->m_conflictCache.insertKey(what,what->path());
} else {
m_Data->m_Cache.insertKey(what,what->path());
@@ -2539,9 +2539,9 @@ bool SvnActions::checkReposLockCache(const TQString&path)
return m_Data->m_repoLockCache.findSingleValid(path,false);
}
-bool SvnActions::checkReposLockCache(const TQString&path,svn::SharedPointer<svn::Status>&t)
+bool SvnActions::checkReposLockCache(const TQString&path,svn::SharedPointer<svn::tqStatus>&t)
{
/// @todo create a method where svn::Status* will be a parameter so no copy is needed but just reading content
return m_Data->m_repoLockCache.findSingleValid(path,t);
}
@@ -2599,7 +2599,7 @@ void SvnActions::customEvent(TQCustomEvent * e)
return;
} else if (e&&e->type()==EVENT_LOGCACHE_STATUS && m_FCThread && m_FCThread->running()) {
FillCacheStatusEvent*fev=(FillCacheStatusEvent*)e;
- emit sigCacheStatus(fev->current(),fev->max());
+ emit sigCachetqStatus(fev->current(),fev->max());
}
}
@@ -2638,11 +2638,11 @@ void SvnActions::removeFromUpdateCache(const TQStringList&what,bool exact_only)
bool SvnActions::isUpdated(const TQString&path)const
{
- svn::SharedPointer<svn::Status> d;
+ svn::SharedPointer<svn::tqStatus> d;
return m_Data->m_UpdateCache.findSingleValid(path,d);
}
-bool SvnActions::getUpdated(const TQString&path,svn::SharedPointer<svn::Status>&d)const
+bool SvnActions::getUpdated(const TQString&path,svn::SharedPointer<svn::tqStatus>&d)const
{
return m_Data->m_UpdateCache.findSingleValid(path,d);
}
@@ -2539,9 +2539,9 @@ bool SvnActions::checkReposLockCache(const TQString&path)
{
- /// @todo create a method where svn::Status* will be a parameter so no copy is needed but just reading content
+ /// @todo create a method where svn::tqStatus* will be a parameter so no copy is needed but just reading content
return m_Data->m_repoLockCache.findSingleValid(path,t);
}